# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Payment'
        db.create_table('paypaladaptive_payment', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('money_currency', self.gf('money.contrib.django.models.fields.CurrencyField')(default=None, max_length=3)),
            ('money', self.gf('money.contrib.django.models.fields.MoneyField')(default=None, no_currency_field=True, max_digits=6, decimal_places=2, blank=True)),
            ('created_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('secret_uuid', self.gf('paypaladaptive.models.UUIDField')(max_length=32)),
            ('debug_request', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('debug_response', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('pay_key', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('transaction_id', self.gf('django.db.models.fields.CharField')(max_length=128, null=True, blank=True)),
            ('status', self.gf('django.db.models.fields.CharField')(default='new', max_length=10)),
            ('status_detail', self.gf('django.db.models.fields.CharField')(max_length=2048)),
        ))
        db.send_create_signal('paypaladaptive', ['Payment'])

        # Adding model 'Refund'
        db.create_table('paypaladaptive_refund', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('money_currency', self.gf('money.contrib.django.models.fields.CurrencyField')(default=None, max_length=3)),
            ('money', self.gf('money.contrib.django.models.fields.MoneyField')(default=None, no_currency_field=True, max_digits=6, decimal_places=2, blank=True)),
            ('created_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('secret_uuid', self.gf('paypaladaptive.models.UUIDField')(max_length=32)),
            ('debug_request', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('debug_response', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('payment', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['paypaladaptive.Payment'], unique=True)),
            ('status', self.gf('django.db.models.fields.CharField')(default='new', max_length=10)),
            ('status_detail', self.gf('django.db.models.fields.CharField')(max_length=2048)),
        ))
        db.send_create_signal('paypaladaptive', ['Refund'])

        # Adding model 'Preapproval'
        db.create_table('paypaladaptive_preapproval', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('money_currency', self.gf('money.contrib.django.models.fields.CurrencyField')(default=None, max_length=3)),
            ('money', self.gf('money.contrib.django.models.fields.MoneyField')(default=None, no_currency_field=True, max_digits=6, decimal_places=2, blank=True)),
            ('created_date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('secret_uuid', self.gf('paypaladaptive.models.UUIDField')(max_length=32)),
            ('debug_request', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('debug_response', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
            ('valid_until_date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(2013, 9, 2, 0, 0))),
            ('preapproval_key', self.gf('django.db.models.fields.CharField')(max_length=255)),
            ('status', self.gf('django.db.models.fields.CharField')(default='new', max_length=10)),
            ('status_detail', self.gf('django.db.models.fields.CharField')(max_length=2048)),
        ))
        db.send_create_signal('paypaladaptive', ['Preapproval'])


    def backwards(self, orm):
        # Deleting model 'Payment'
        db.delete_table('paypaladaptive_payment')

        # Deleting model 'Refund'
        db.delete_table('paypaladaptive_refund')

        # Deleting model 'Preapproval'
        db.delete_table('paypaladaptive_preapproval')


    models = {
        'paypaladaptive.payment': {
            'Meta': {'object_name': 'Payment'},
            'created_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'debug_request': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'debug_response': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'money': ('money.contrib.django.models.fields.MoneyField', [], {'default': 'None', 'no_currency_field': 'True', 'max_digits': '6', 'decimal_places': '2', 'blank': 'True'}),
            'money_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': 'None', 'max_length': '3'}),
            'pay_key': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'secret_uuid': ('paypaladaptive.models.UUIDField', [], {'max_length': '32'}),
            'status': ('django.db.models.fields.CharField', [], {'default': "'new'", 'max_length': '10'}),
            'status_detail': ('django.db.models.fields.CharField', [], {'max_length': '2048'}),
            'transaction_id': ('django.db.models.fields.CharField', [], {'max_length': '128', 'null': 'True', 'blank': 'True'})
        },
        'paypaladaptive.preapproval': {
            'Meta': {'object_name': 'Preapproval'},
            'created_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'debug_request': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'debug_response': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'money': ('money.contrib.django.models.fields.MoneyField', [], {'default': 'None', 'no_currency_field': 'True', 'max_digits': '6', 'decimal_places': '2', 'blank': 'True'}),
            'money_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': 'None', 'max_length': '3'}),
            'preapproval_key': ('django.db.models.fields.CharField', [], {'max_length': '255'}),
            'secret_uuid': ('paypaladaptive.models.UUIDField', [], {'max_length': '32'}),
            'status': ('django.db.models.fields.CharField', [], {'default': "'new'", 'max_length': '10'}),
            'status_detail': ('django.db.models.fields.CharField', [], {'max_length': '2048'}),
            'valid_until_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime(2013, 9, 2, 0, 0)'})
        },
        'paypaladaptive.refund': {
            'Meta': {'object_name': 'Refund'},
            'created_date': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'debug_request': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'debug_response': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'money': ('money.contrib.django.models.fields.MoneyField', [], {'default': 'None', 'no_currency_field': 'True', 'max_digits': '6', 'decimal_places': '2', 'blank': 'True'}),
            'money_currency': ('money.contrib.django.models.fields.CurrencyField', [], {'default': 'None', 'max_length': '3'}),
            'payment': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['paypaladaptive.Payment']", 'unique': 'True'}),
            'secret_uuid': ('paypaladaptive.models.UUIDField', [], {'max_length': '32'}),
            'status': ('django.db.models.fields.CharField', [], {'default': "'new'", 'max_length': '10'}),
            'status_detail': ('django.db.models.fields.CharField', [], {'max_length': '2048'})
        }
    }

    complete_apps = ['paypaladaptive']


#!/usr/bin/env python

import os
import sys

from optparse import OptionParser

from django.conf import settings
from django.core.management import call_command


def main():
    """
    The entry point for the script. This script is fairly basic. Here is a
    quick example of how to use it::

        app_test_runner.py [path-to-app]

    You must have Django on the PYTHONPATH prior to running this script. This
    script basically will bootstrap a Django environment for you.

    By default this script with use SQLite and an in-memory database. If you
    are using Python 2.5 it will just work out of the box for you.

    TODO: show more options here.
    """
    parser = OptionParser()
    parser.add_option("--DATABASE_ENGINE", dest="DATABASE_ENGINE", default="sqlite3")
    parser.add_option("--DATABASE_NAME", dest="DATABASE_NAME", default="")
    parser.add_option("--DATABASE_USER", dest="DATABASE_USER", default="")
    parser.add_option("--DATABASE_PASSWORD", dest="DATABASE_PASSWORD", default="")
    parser.add_option("--SITE_ID", dest="SITE_ID", type="int", default=1)

    options, args = parser.parse_args()

    # check for app in args
    try:
        app_path = args[0]
    except IndexError:
        print "You did not provide an app path."
        raise SystemExit
    else:
        if app_path.endswith("/"):
            app_path = app_path[:-1]
        parent_dir, app_name = os.path.split(app_path)
        sys.path.insert(0, parent_dir)

    settings.configure(**{
        "PAYPAL_APPLICATION_ID": 'fake',
        "PAYPAL_USERID": 'fake',
        "PAYPAL_PASSWORD": 'fake',
        "PAYPAL_SIGNATURE": 'test',
        "PAYPAL_EMAIL": "fake@fake.com",
        "DATABASES": {
            'default': {
                "ENGINE": 'django.db.backends.%s' % options.DATABASE_ENGINE,
                "NAME": options.DATABASE_NAME,
                "USER": options.DATABASE_USER,
                "PASSWORD": options.DATABASE_PASSWORD,
            }
        },
        "SITE_ID": options.SITE_ID,
        "ROOT_URLCONF": app_name + ".urls",
        "TEMPLATE_LOADERS": (
            "django.template.loaders.filesystem.Loader",
            "django.template.loaders.app_directories.Loader",
            "django.template.loaders.eggs.Loader",
        ),
        "TEMPLATE_DIRS": (
            os.path.join(os.path.dirname(__file__), "templates"),
        ),
        "INSTALLED_APPS": (
            # HACK: the admin app should *not* be required. Need to spend some
            # time looking into this. Django #8523 has a patch for this issue,
            # but was wrongly attached to that ticket. It should have its own
            # ticket.
            "django.contrib.auth",
            "django.contrib.contenttypes",
            "django.contrib.sessions",
            "django.contrib.sites",
            app_name,
        ),
        "LOGGING": {
            'version': 1,
            'disable_existing_loggers': False,
            'formatters': {
                'verbose': {
                    'format': '%(levelname)s %(asctime)s %(module)s %(process)d '
                              '%(thread)d %(message)s'
                },
            },
            'handlers': {
                'console': {
                    'level': 'DEBUG',
                    'class': 'logging.StreamHandler',
                    'formatter': 'verbose',
                }
            },
            'loggers': {
                app_name: {
                    'handlers': ['console'],
                    'level': 'DEBUG',
                    'formatter': 'verbose',
                    'propagate': True,
                }
            }
        }
    })
    call_command("test", *args[1:])

if __name__ == "__main__":
    main()



from tests import *
from ipn import TestPaymentIPN, TestPreapprovalIPN, TestIPNVerification
from preapproval_return_url import TestPreapprovalReturnURL
from payment_return_url import TestPaymentReturnURL
from payment_response import TestPaymentResponses



from django.contrib import admin
from models import Payment, Preapproval, Refund

class PreapprovalAdmin(admin.ModelAdmin):
    list_display = ('preapproval_key', 'valid_until_date', 'status')

class PaymentAdmin(admin.ModelAdmin):
    pass

class RefundAdmin(admin.ModelAdmin):
    pass

# admin.site.register(Payment)
# admin.site.register(Preapproval, PreapprovalAdmin)
# admin.site.register(Refund)